@@ -20,13 +20,13 @@ demo(const char *latin1_infinitive)
 	char *lower_latin1;
 
 	lower_latin1 = verbiste_tolower_latin1(latin1_infinitive);
-	person_array = verbiste_conjugate(lower_latin1, mode, tense);
+	person_array = verbiste_conjugate(lower_latin1, mode, tense, 0);
 	verbiste_free_string(lower_latin1);
 
 	if (person_array == NULL)
 	{
 	    printf("Unknown infinitive.\n");
-	    return -1;
+	    return EXIT_FAILURE;
 	}
 
 	printf("- %s %s:\n",
@@ -34,12 +34,10 @@ demo(const char *latin1_infinitive)
 	    (const char*) verbiste_get_tense_name(tense));
 
 
-	//for (i = 0; vec[i].inflections != NULL; i++)
 	for (i = 0; person_array[i] != NULL; i++)
 	{
 	    size_t j;
 
-	    //for (j = 0; vec[i].inflections[j] != NULL; j++)
 	    for (j = 0; person_array[i][j] != NULL; j++)
 	    {
 		if (j != 0)
@@ -52,7 +50,7 @@ demo(const char *latin1_infinitive)
 	verbiste_free_person_array(person_array);
     }
     printf("-\n");
-    return 0;
+    return EXIT_SUCCESS;
 }
 
 
@@ -64,8 +62,8 @@ int main( int argc, char *argv[])
 
     if (argc < 2)
     {
-	printf("french-conjugator-c demo for the C api of libverbiste\n");
-	printf("Usage: french-conjugator-c word\n");
+	printf("conjugator.c: demo of the C API of Verbiste\n");
+	printf("Usage: conjugator VERB\n");
 	return EXIT_FAILURE;
     }
 
