@@ -1,8 +1,8 @@
-/*  $Id: french-conjugator.cpp,v 1.9 2005/03/13 04:03:26 sarrazip Exp $
+/*  $Id: french-conjugator.cpp,v 1.12 2006/08/29 01:13:25 sarrazip Exp $
     french-conjugator.cpp - Conjugation of French verbs
 
     verbiste - French conjugation system
-    Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2006 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -31,6 +31,8 @@
 #include <getopt.h>
 #endif
 
+#include <langinfo.h>
+
 #include <iostream>
 #include <vector>
 
@@ -60,8 +62,8 @@ class ConjugatorCommand : public Command
 {
 public:
 
-    ConjugatorCommand() throw(logic_error)
-      : Command(),
+    ConjugatorCommand(bool utf8Mode) throw(logic_error)
+      : Command(utf8Mode),
 	reqMode(INVALID_MODE),
 	reqTense(INVALID_TENSE),
 	reqTemplate(),
@@ -130,7 +132,12 @@ ConjugatorCommand::displayTense(FrenchVerbDictionary &fvd,
 	{
 	    if (i != p->begin())
 		cout << ", ";
-	    cout << *i;
+	    string s = *i;
+
+	    if (utf8Mode)
+		s = fvd.latin1ToUTF8(s);
+
+	    cout << s;
 	}
 	cout << "\n";
     }
@@ -197,6 +204,8 @@ ConjugatorCommand::processInputWord(const string &inputWord)
 }
 
 
+#ifdef HAVE_GETOPT_LONG
+
 static
 void
 displayVersionNo()
@@ -217,7 +226,7 @@ displayHelp()
 
     cout <<
 "\n"
-"Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>\n"
+"Copyright (C) 2003-2006 Pierre Sarrazin <http://sarrazip.com/>\n"
 "This program is free software; you may redistribute it under the terms of\n"
 "the GNU General Public License.  This program has absolutely no warranty.\n"
     ;
@@ -237,10 +246,17 @@ displayHelp()
     ;
 }
 
+#endif  /* ndef HAVE_GETOPT_LONG */
+
 
 int
 main(int argc, char *argv[])
 {
+    setlocale(LC_CTYPE, "");
+    bool utf8Mode = (strcmp(nl_langinfo(CODESET), "UTF-8") == 0);
+	// See http://www.cl.cam.ac.uk/~mgk25/unicode.html
+	// re: "How should the UTF-8 mode be activated?"
+
     Mode reqMode = INVALID_MODE;
     Tense reqTense = INVALID_TENSE;
     string reqTemplate;
@@ -311,7 +327,7 @@ main(int argc, char *argv[])
 
     #endif  /* ndef HAVE_GETOPT_LONG */
 
-    ConjugatorCommand cmd;
+    ConjugatorCommand cmd(utf8Mode);
     cmd.reqMode = reqMode;
     cmd.reqTense = reqTense;
     cmd.reqTemplate = reqTemplate;
