@@ -1,8 +1,8 @@
-/*  $Id: french-deconjugator.cpp,v 1.8 2005/03/13 04:03:26 sarrazip Exp $
+/*  $Id: french-deconjugator.cpp,v 1.10 2006/07/08 19:20:05 sarrazip Exp $
     french-deconjugator.cpp - Analyzer of conjugated French verbs
 
     verbiste - French conjugation system
-    Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2006 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -31,6 +31,8 @@
 #include <getopt.h>
 #endif
 
+#include <langinfo.h>
+
 #include <iostream>
 #include <vector>
 
@@ -56,8 +58,8 @@ class DeconjugatorCommand : public Command
 {
 public:
 
-    DeconjugatorCommand() throw(logic_error)
-      : Command()
+    DeconjugatorCommand(bool utf8Mode) throw(logic_error)
+      : Command(utf8Mode)
     {
     }
 
@@ -86,8 +88,22 @@ DeconjugatorCommand::processInputWord(const string &inputWord)
 					    it != v.end(); it++)
     {
 	const InflectionDesc &d = *it;
+	string inf = d.infinitive;
+
+	if (utf8Mode)
+	{
+	    try
+	    {
+		inf = fvd->latin1ToUTF8(inf);
+	    }
+	    catch (int)
+	    {
+		// Conversion failed. Leave 'inf' as is.
+	    }
+	}
+
 	cout 
-	    << d.infinitive
+	    << inf
 	    << ", " << FrenchVerbDictionary::getModeName(d.mtpn.mode)
 	    << ", " << FrenchVerbDictionary::getTenseName(d.mtpn.tense)
 	    << ", " << int(d.mtpn.person)
@@ -118,7 +134,7 @@ displayHelp()
 
     cout <<
 "\n"
-"Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>\n"
+"Copyright (C) 2003-2006 Pierre Sarrazin <http://sarrazip.com/>\n"
 "This program is free software; you may redistribute it under the terms of\n"
 "the GNU General Public License.  This program has absolutely no warranty.\n"
     ;
@@ -138,6 +154,9 @@ displayHelp()
 int
 main(int argc, char *argv[])
 {
+    setlocale(LC_CTYPE, "");
+    bool utf8Mode = (strcmp(nl_langinfo(CODESET), "UTF-8") == 0);
+
     #ifdef HAVE_GETOPT_LONG
 
     /*  Interpret the command-line options:
@@ -172,7 +191,7 @@ main(int argc, char *argv[])
 
     #endif  /* ndef HAVE_GETOPT_LONG */
 
-    DeconjugatorCommand cmd;
+    DeconjugatorCommand cmd(utf8Mode);
 
     return cmd.run(argc - optind, argv + optind);
 }
