@@ -1,4 +1,4 @@
-/*  $Id: gnome-app.cpp,v 1.6 2005/04/24 18:17:08 sarrazip Exp $
+/*  $Id: gnome-app.cpp,v 1.7 2006/08/28 19:05:25 sarrazip Exp $
     gtk-app.cpp - GTK+ application main function
 
     verbiste - French conjugation system
@@ -20,7 +20,7 @@
     02111-1307, USA.
 */
 
-#include "main-window.h"
+#include "gtk/main-window.h"
 #include "gui/conjugation.h"
 
 #include <libintl.h>
@@ -61,7 +61,7 @@ get_poptContext(GnomeProgram *program)
 int
 main(int argc, char *argv[])
 {
-    bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
+    bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
     textdomain(GETTEXT_PACKAGE);
 
