@@ -1,4 +1,4 @@
-/*  $Id: panel-applet.cpp,v 1.11 2005/04/24 18:17:08 sarrazip Exp $
+/*  $Id: panel-applet.cpp,v 1.12 2006/08/28 19:05:25 sarrazip Exp $
     panel-applet.cpp - GNOME Panel applet main functions
 
     verbiste - French conjugation system
@@ -20,7 +20,7 @@
     02111-1307, USA.
 */
 
-#include "main-window.h"
+#include "gtk/main-window.h"
 #include "gui/conjugation.h"
 
 #include <panel-applet.h>
