@@ -1,4 +1,4 @@
-/*  $Id: FrenchVerbDictionary.cpp,v 1.18 2005/03/13 04:03:26 sarrazip Exp $
+/*  $Id: FrenchVerbDictionary.cpp,v 1.19 2006/08/26 02:19:01 sarrazip Exp $
     FrenchVerbDictionary.cpp - Dictionary of verbs and conjugation templates
 
     verbiste - French conjugation system
@@ -655,7 +655,11 @@ FrenchVerbDictionary::latin1ToUTF8(const string &latin1String) const throw(int)
     char *inbuf = strcpy(new char[inbytesleft], latin1String.c_str());
     char *outbuf = new char[outbytesleft];
 
-    char *in = inbuf;
+    ICONV_CONST char *in = inbuf;
+	/*  ICONV_CONST is defined by iconv.m4 to 'const' if the 2nd
+	    argument of iconv() requires const, as is the case under
+	    FreeBSD 6.1 with GCC 3.4.4 [2006-07-10].
+	*/
     char *out = outbuf;
     if (iconv(toUTF8, &in, &inbytesleft, &out, &outbytesleft) == (size_t) -1)
     {
@@ -681,7 +685,7 @@ FrenchVerbDictionary::utf8ToLatin1(const string &utf8String) const throw(int)
     char *inbuf = strcpy(new char[inbytesleft], utf8String.c_str());
     char *outbuf = new char[outbytesleft];
 
-    char *in = inbuf;
+    ICONV_CONST char *in = inbuf;
     char *out = outbuf;
     if (iconv(toLatin1, &in, &inbytesleft, &out, &outbytesleft) == (size_t) -1)
     {
